import _omit from 'lodash/omit';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/*
 * This file is part of the nivo project.
 *
 * Copyright 2016-present, Raphaël Benitte.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
import React, { Component } from 'react';

import { TransitionMotion, spring } from 'react-motion';

import compose from 'recompose/compose';
import defaultProps from 'recompose/defaultProps';
import withPropsOnChange from 'recompose/withPropsOnChange';
import withStateHandlers from 'recompose/withStateHandlers';
import pure from 'recompose/pure';
import { pack } from 'd3-hierarchy';
import { withHierarchy, withTheme, withColors, withDimensions, withMotion } from '../../../hocs';
import { computeNodePath } from '../../../lib/hierarchy';
import Container from '../Container';
import { getAccessorFor, getLabelGenerator } from '../../../lib/propertiesConverters';
import { getInheritedColorGenerator } from '../../../lib/colors';
import { bubblePropTypes, bubbleDefaultProps } from './props';

var ignoreProps = ['enableLabel', 'label', 'labelFormat', 'labelTextColor', 'labelSkipRadius', 'labelTextDY', 'transitionDuration', 'transitionEasing'];

var computeZoom = function computeZoom(nodes, currentNodePath, width, height) {
    var currentNode = nodes.find(function (_ref) {
        var path = _ref.path;
        return path === currentNodePath;
    });
    if (currentNode) {
        var ratio = Math.min(width, height) / (currentNode.r * 2);
        var offsetX = width / 2 - currentNode.x * ratio;
        var offsetY = height / 2 - currentNode.y * ratio;
        nodes.forEach(function (node) {
            node.r = node.r * ratio;
            node.x = node.x * ratio + offsetX;
            node.y = node.y * ratio + offsetY;
        });
    }
};

var BubbleCanvas = function (_Component) {
    _inherits(BubbleCanvas, _Component);

    function BubbleCanvas() {
        _classCallCheck(this, BubbleCanvas);

        return _possibleConstructorReturn(this, _Component.apply(this, arguments));
    }

    BubbleCanvas.prototype.componentDidMount = function componentDidMount() {
        this.ctx = this.surface.getContext('2d');
        this.draw(this.props);
    };

    BubbleCanvas.prototype.componentDidUpdate = function componentDidUpdate() {
        this.ctx = this.surface.getContext('2d');
        this.draw(this.props);
    };

    BubbleCanvas.prototype.draw = function draw(props) {
        var _this2 = this;

        var root = props.root,
            getIdentity = props.getIdentity,
            leavesOnly = props.leavesOnly,
            pixelRatio = props.pixelRatio,
            pack = props.pack,
            width = props.width,
            height = props.height,
            margin = props.margin,
            outerWidth = props.outerWidth,
            outerHeight = props.outerHeight,
            getColor = props.getColor,
            borderWidth = props.borderWidth,
            getBorderColor = props.getBorderColor,
            enableLabel = props.enableLabel,
            getLabel = props.getLabel,
            labelSkipRadius = props.labelSkipRadius,
            getLabelTextColor = props.getLabelTextColor;


        this.surface.width = outerWidth * pixelRatio;
        this.surface.height = outerHeight * pixelRatio;

        this.ctx.scale(pixelRatio, pixelRatio);

        this.ctx.clearRect(0, 0, outerWidth, outerHeight);

        // assign a unique id depending on node path to each node
        root.each(function (node) {
            node.id = getIdentity(node.data);
            node.path = computeNodePath(node, getIdentity);
        });

        pack(root);

        var nodes = leavesOnly ? root.leaves() : root.descendants();
        nodes = nodes.map(function (node) {
            node.color = getColor(_extends({}, node.data, { depth: node.depth }));

            return node;
        });

        this.ctx.translate(margin.left, margin.top);

        nodes.forEach(function (node) {
            _this2.ctx.save();

            if (borderWidth > 0) {
                _this2.ctx.strokeStyle = getBorderColor(node);
                _this2.ctx.lineWidth = borderWidth;
            }

            _this2.ctx.beginPath();
            _this2.ctx.arc(node.x, node.y, node.r, 0, 2 * Math.PI);
            _this2.ctx.fillStyle = node.color;
            _this2.ctx.fill();

            if (borderWidth > 0) {
                _this2.ctx.stroke();
            }
        });

        if (enableLabel) {
            this.ctx.textAlign = 'center';
            this.ctx.textBaseline = 'middle';

            // draw labels on top
            nodes.filter(function (_ref2) {
                var r = _ref2.r;
                return r > labelSkipRadius;
            }).forEach(function (node) {
                var label = getLabel(node);
                var labelTextColor = getLabelTextColor(node);

                _this2.ctx.fillStyle = labelTextColor;
                _this2.ctx.fillText(label, node.x, node.y);
            });
        }
    };

    BubbleCanvas.prototype.render = function render() {
        var _this3 = this;

        var _props = this.props,
            outerWidth = _props.outerWidth,
            outerHeight = _props.outerHeight,
            pixelRatio = _props.pixelRatio,
            isInteractive = _props.isInteractive,
            theme = _props.theme;


        return React.createElement(
            Container,
            { isInteractive: isInteractive, theme: theme },
            function (_ref3) {
                var showTooltip = _ref3.showTooltip,
                    hideTooltip = _ref3.hideTooltip;
                return React.createElement('canvas', {
                    ref: function ref(surface) {
                        _this3.surface = surface;
                    },
                    width: outerWidth * pixelRatio,
                    height: outerHeight * pixelRatio,
                    style: {
                        width: outerWidth,
                        height: outerHeight
                    }
                });
            }
        );
    };

    return BubbleCanvas;
}(Component);

/*
const BubbleCanvas = ({
    root,
    getIdentity,

    leavesOnly,
    namespace,

    pack,

    // dimensions
    width,
    height,
    margin,
    outerWidth,
    outerHeight,

    // theming
    theme,
    getColor,

    // motion
    animate,
    motionStiffness,
    motionDamping,

    // interactivity
    isInteractive,
    onClick,

    children,

    // zooming
    isZoomable,
    zoomToNode,
    currentNodePath,
}) => {
    // assign a unique id depending on node path to each node
    root.each(node => {
        node.id = getIdentity(node.data)
        node.path = computeNodePath(node, getIdentity)
    })

    pack(root)

    let nodes = leavesOnly ? root.leaves() : root.descendants()
    nodes = nodes.map(node => {
        node.color = getColor({ ...node.data, depth: node.depth })

        return node
    })

    if (currentNodePath) computeZoom(nodes, currentNodePath, width, height)

    let wrapperTag
    let containerTag

    const wrapperProps = {}
    const containerProps = {}

    if (namespace === 'svg') {
        wrapperTag = 'svg'
        containerTag = 'g'

        wrapperProps.width = outerWidth
        wrapperProps.height = outerHeight
        wrapperProps.xmlns = 'http://www.w3.org/2000/svg'
        containerProps.transform = `translate(${margin.left},${margin.top})`
    } else {
        wrapperTag = 'div'
        containerTag = 'div'

        wrapperProps.style = {
            position: 'relative',
            width: outerWidth,
            height: outerHeight,
        }
        containerProps.style = Object.assign({}, margin, {
            position: 'absolute',
        })
    }

    let nodeOnClick = noop
    if (isInteractive) {
        if (isZoomable) {
            nodeOnClick = node => () => {
                onClick(node)
                zoomToNode(node.path)
            }
        } else {
            nodeOnClick = node => () => onClick(node)
        }
    }

    if (!animate) {
        return (
            <Container isInteractive={isInteractive} theme={theme}>
                {({ showTooltip, hideTooltip }) =>
                    React.createElement(
                        wrapperTag,
                        wrapperProps,
                        React.createElement(
                            containerTag,
                            containerProps,
                            children(
                                nodes.map(node => ({
                                    key: node.path,
                                    data: node,
                                    style: _.pick(node, ['scale', 'r', 'x', 'y', 'color']),
                                    onClick: nodeOnClick(node),
                                })),
                                { showTooltip, hideTooltip, theme }
                            )
                        )
                    )}
            </Container>
        )
    }

    const springConfig = {
        stiffness: motionStiffness,
        damping: motionDamping,
    }

    return null
}

BubbleCanvas.propTypes = _.omit(bubblePropTypes, ignoreProps)
*/

var enhance = compose(defaultProps(_omit(bubbleDefaultProps, ignoreProps)), withHierarchy(), withDimensions(), withTheme(), withMotion(), withColors({ defaultColorBy: 'depth' }), withPropsOnChange(['identity'], function (_ref4) {
    var identity = _ref4.identity;
    return {
        getIdentity: getAccessorFor(identity)
    };
}), withPropsOnChange(['label', 'labelFormat'], function (_ref5) {
    var label = _ref5.label,
        labelFormat = _ref5.labelFormat;
    return {
        getLabel: getLabelGenerator(label, labelFormat)
    };
}), withPropsOnChange(['borderColor'], function (_ref6) {
    var borderColor = _ref6.borderColor;
    return {
        getBorderColor: getInheritedColorGenerator(borderColor)
    };
}), withPropsOnChange(['labelTextColor'], function (_ref7) {
    var labelTextColor = _ref7.labelTextColor;
    return {
        getLabelTextColor: getInheritedColorGenerator(labelTextColor)
    };
}), withPropsOnChange(['width', 'height', 'padding'], function (_ref8) {
    var width = _ref8.width,
        height = _ref8.height,
        padding = _ref8.padding;
    return {
        pack: pack().size([width, height]).padding(padding)
    };
}), withStateHandlers(function (_ref9) {
    var _ref9$currentNodePath = _ref9.currentNodePath,
        currentNodePath = _ref9$currentNodePath === undefined ? null : _ref9$currentNodePath;
    return {
        currentNodePath: currentNodePath
    };
}, {
    zoomToNode: function zoomToNode(_ref10) {
        var currentNodePath = _ref10.currentNodePath;
        return function (path) {
            if (path === currentNodePath) return { currentNodePath: null };
            return { currentNodePath: path };
        };
    }
}), pure);

export default enhance(BubbleCanvas);