'use strict';

exports.__esModule = true;

var _omit2 = require('lodash/omit');

var _omit3 = _interopRequireDefault(_omit2);

var _pick2 = require('lodash/pick');

var _pick3 = _interopRequireDefault(_pick2);

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; /*
                                                                                                                                                                                                                                                                   * This file is part of the nivo project.
                                                                                                                                                                                                                                                                   *
                                                                                                                                                                                                                                                                   * Copyright 2016-present, Raphaël Benitte.
                                                                                                                                                                                                                                                                   *
                                                                                                                                                                                                                                                                   * For the full copyright and license information, please view the LICENSE
                                                                                                                                                                                                                                                                   * file that was distributed with this source code.
                                                                                                                                                                                                                                                                   */


var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactMotion = require('react-motion');

var _compose = require('recompose/compose');

var _compose2 = _interopRequireDefault(_compose);

var _defaultProps = require('recompose/defaultProps');

var _defaultProps2 = _interopRequireDefault(_defaultProps);

var _withPropsOnChange = require('recompose/withPropsOnChange');

var _withPropsOnChange2 = _interopRequireDefault(_withPropsOnChange);

var _withStateHandlers = require('recompose/withStateHandlers');

var _withStateHandlers2 = _interopRequireDefault(_withStateHandlers);

var _pure = require('recompose/pure');

var _pure2 = _interopRequireDefault(_pure);

var _d3Hierarchy = require('d3-hierarchy');

var _hocs = require('../../../hocs');

var _colors = require('../../../lib/colors');

var _noop = require('../../../lib/noop');

var _noop2 = _interopRequireDefault(_noop);

var _hierarchy = require('../../../lib/hierarchy');

var _Container = require('../Container');

var _Container2 = _interopRequireDefault(_Container);

var _propertiesConverters = require('../../../lib/propertiesConverters');

var _props = require('./props');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var ignoreProps = ['borderWidth', 'borderColor', 'enableLabel', 'label', 'labelFormat', 'labelTextColor', 'labelSkipRadius', 'labelTextDY', 'transitionDuration', 'transitionEasing'];

var nodeWillEnter = function nodeWillEnter(_ref) {
    var data = _ref.data;
    return _extends({
        scale: 0,
        r: 0,
        x: data.x,
        y: data.y
    }, (0, _colors.colorMotionSpring)(data.color));
};

var nodeWillLeave = function nodeWillLeave(springConfig) {
    return function (_ref2) {
        var data = _ref2.data;
        return _extends({
            scale: (0, _reactMotion.spring)(0, springConfig),
            r: (0, _reactMotion.spring)(0, springConfig),
            x: (0, _reactMotion.spring)(data.x, springConfig),
            y: (0, _reactMotion.spring)(data.y, springConfig)
        }, (0, _colors.colorMotionSpring)(data.color, springConfig));
    };
};

var computeZoom = function computeZoom(nodes, currentNodePath, width, height) {
    var currentNode = nodes.find(function (_ref3) {
        var path = _ref3.path;
        return path === currentNodePath;
    });
    if (currentNode) {
        var ratio = Math.min(width, height) / (currentNode.r * 2);
        var offsetX = width / 2 - currentNode.x * ratio;
        var offsetY = height / 2 - currentNode.y * ratio;
        nodes.forEach(function (node) {
            node.r = node.r * ratio;
            node.x = node.x * ratio + offsetX;
            node.y = node.y * ratio + offsetY;
        });
    }
};

var BubblePlaceholders = function BubblePlaceholders(_ref4) {
    var root = _ref4.root,
        getIdentity = _ref4.getIdentity,
        leavesOnly = _ref4.leavesOnly,
        namespace = _ref4.namespace,
        pack = _ref4.pack,
        width = _ref4.width,
        height = _ref4.height,
        margin = _ref4.margin,
        outerWidth = _ref4.outerWidth,
        outerHeight = _ref4.outerHeight,
        theme = _ref4.theme,
        getColor = _ref4.getColor,
        animate = _ref4.animate,
        motionStiffness = _ref4.motionStiffness,
        motionDamping = _ref4.motionDamping,
        isInteractive = _ref4.isInteractive,
        onClick = _ref4.onClick,
        children = _ref4.children,
        isZoomable = _ref4.isZoomable,
        zoomToNode = _ref4.zoomToNode,
        currentNodePath = _ref4.currentNodePath;

    // assign a unique id depending on node path to each node
    root.each(function (node) {
        node.id = getIdentity(node.data);
        node.path = (0, _hierarchy.computeNodePath)(node, getIdentity);
    });

    pack(root);

    var nodes = leavesOnly ? root.leaves() : root.descendants();
    nodes = nodes.map(function (node) {
        node.color = getColor(_extends({}, node.data, { depth: node.depth }));

        return node;
    });

    if (currentNodePath) computeZoom(nodes, currentNodePath, width, height);

    var wrapperTag = void 0;
    var containerTag = void 0;

    var wrapperProps = {};
    var containerProps = {};

    if (namespace === 'svg') {
        wrapperTag = 'svg';
        containerTag = 'g';

        wrapperProps.width = outerWidth;
        wrapperProps.height = outerHeight;
        wrapperProps.xmlns = 'http://www.w3.org/2000/svg';
        containerProps.transform = 'translate(' + margin.left + ',' + margin.top + ')';
    } else {
        wrapperTag = 'div';
        containerTag = 'div';

        wrapperProps.style = {
            position: 'relative',
            width: outerWidth,
            height: outerHeight
        };
        containerProps.style = Object.assign({}, margin, {
            position: 'absolute'
        });
    }

    var nodeOnClick = _noop2.default;
    if (isInteractive) {
        if (isZoomable) {
            nodeOnClick = function nodeOnClick(node) {
                return function () {
                    onClick(node);
                    zoomToNode(node.path);
                };
            };
        } else {
            nodeOnClick = function nodeOnClick(node) {
                return function () {
                    return onClick(node);
                };
            };
        }
    }

    if (!animate) {
        return _react2.default.createElement(
            _Container2.default,
            { isInteractive: isInteractive, theme: theme },
            function (_ref5) {
                var showTooltip = _ref5.showTooltip,
                    hideTooltip = _ref5.hideTooltip;
                return _react2.default.createElement(wrapperTag, wrapperProps, _react2.default.createElement(containerTag, containerProps, children(nodes.map(function (node) {
                    return {
                        key: node.path,
                        data: node,
                        style: (0, _pick3.default)(node, ['scale', 'r', 'x', 'y', 'color']),
                        onClick: nodeOnClick(node)
                    };
                }), { showTooltip: showTooltip, hideTooltip: hideTooltip, theme: theme })));
            }
        );
    }

    var springConfig = {
        stiffness: motionStiffness,
        damping: motionDamping
    };

    return _react2.default.createElement(
        _Container2.default,
        { isInteractive: isInteractive, theme: theme },
        function (_ref6) {
            var showTooltip = _ref6.showTooltip,
                hideTooltip = _ref6.hideTooltip;
            return _react2.default.createElement(wrapperTag, wrapperProps, _react2.default.createElement(
                _reactMotion.TransitionMotion,
                {
                    willEnter: nodeWillEnter,
                    willLeave: nodeWillLeave(springConfig),
                    styles: nodes.map(function (node) {
                        return {
                            key: node.path,
                            data: node,
                            style: _extends({
                                scale: (0, _reactMotion.spring)(1, springConfig),
                                r: (0, _reactMotion.spring)(node.r, springConfig),
                                x: (0, _reactMotion.spring)(node.x, springConfig),
                                y: (0, _reactMotion.spring)(node.y, springConfig),
                                opacity: (0, _reactMotion.spring)(1, springConfig)
                            }, (0, _colors.colorMotionSpring)(node.color, springConfig))
                        };
                    })
                },
                function (interpolatedStyles) {
                    return _react2.default.createElement(containerTag, containerProps, children(interpolatedStyles.map(function (interpolatedStyle) {
                        interpolatedStyle.style.color = (0, _colors.getInterpolatedColor)(interpolatedStyle.style);
                        interpolatedStyle.onClick = nodeOnClick(interpolatedStyle.data);

                        return interpolatedStyle;
                    }), { showTooltip: showTooltip, hideTooltip: hideTooltip, theme: theme }));
                }
            ));
        }
    );
};

BubblePlaceholders.propTypes = (0, _omit3.default)(_props.bubblePropTypes, ignoreProps);

var enhance = (0, _compose2.default)((0, _defaultProps2.default)((0, _omit3.default)(_props.bubbleDefaultProps, ignoreProps)), (0, _hocs.withHierarchy)(), (0, _hocs.withDimensions)(), (0, _hocs.withTheme)(), (0, _hocs.withMotion)(), (0, _hocs.withColors)({ defaultColorBy: 'depth' }), (0, _withPropsOnChange2.default)(['identity'], function (_ref7) {
    var identity = _ref7.identity;
    return {
        getIdentity: (0, _propertiesConverters.getAccessorFor)(identity)
    };
}), (0, _withPropsOnChange2.default)(['width', 'height', 'padding'], function (_ref8) {
    var width = _ref8.width,
        height = _ref8.height,
        padding = _ref8.padding;
    return {
        pack: (0, _d3Hierarchy.pack)().size([width, height]).padding(padding)
    };
}), (0, _withStateHandlers2.default)(function (_ref9) {
    var _ref9$currentNodePath = _ref9.currentNodePath,
        currentNodePath = _ref9$currentNodePath === undefined ? null : _ref9$currentNodePath;
    return {
        currentNodePath: currentNodePath
    };
}, {
    zoomToNode: function zoomToNode(_ref10) {
        var currentNodePath = _ref10.currentNodePath;
        return function (path) {
            if (path === currentNodePath) return { currentNodePath: null };
            return { currentNodePath: path };
        };
    }
}), _pure2.default);

exports.default = enhance(BubblePlaceholders);